Class BetaComputerUsePreviewTool
-
- All Implemented Interfaces:
public final class BetaComputerUsePreviewToolA tool that controls a virtual computer. Learn more about the computer tool.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaComputerUsePreviewTool.BuilderA builder for BetaComputerUsePreviewTool.
public final classBetaComputerUsePreviewTool.EnvironmentThe type of computer environment to control.
-
Method Summary
Modifier and Type Method Description final LongdisplayHeight()The height of the computer display. final LongdisplayWidth()The width of the computer display. final BetaComputerUsePreviewTool.Environmentenvironment()The type of computer environment to control. final JsonValue_type()The type of the computer use tool. final JsonField<Long>_displayHeight()Returns the raw JSON value of displayHeight. final JsonField<Long>_displayWidth()Returns the raw JSON value of displayWidth. final JsonField<BetaComputerUsePreviewTool.Environment>_environment()Returns the raw JSON value of environment. final Map<String, JsonValue>_additionalProperties()final BetaComputerUsePreviewTool.BuildertoBuilder()final BetaComputerUsePreviewToolvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaComputerUsePreviewTool.Builderbuilder()Returns a mutable builder for constructing an instance of BetaComputerUsePreviewTool. -
-
Method Detail
-
displayHeight
final Long displayHeight()
The height of the computer display.
-
displayWidth
final Long displayWidth()
The width of the computer display.
-
environment
final BetaComputerUsePreviewTool.Environment environment()
The type of computer environment to control.
-
_type
final JsonValue _type()
The type of the computer use tool. Always
computer_use_preview.Expected to always return the following:
JsonValue.from("computer_use_preview")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_displayHeight
final JsonField<Long> _displayHeight()
Returns the raw JSON value of displayHeight.
Unlike displayHeight, this method doesn't throw if the JSON field has an unexpected type.
-
_displayWidth
final JsonField<Long> _displayWidth()
Returns the raw JSON value of displayWidth.
Unlike displayWidth, this method doesn't throw if the JSON field has an unexpected type.
-
_environment
final JsonField<BetaComputerUsePreviewTool.Environment> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaComputerUsePreviewTool.Builder toBuilder()
-
validate
final BetaComputerUsePreviewTool validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaComputerUsePreviewTool.Builder builder()
Returns a mutable builder for constructing an instance of BetaComputerUsePreviewTool.
The following fields are required:
.displayHeight() .displayWidth() .environment()
-
-
-
-