Class BetaResponseCodeInterpreterCallCodeDeltaEvent
-
- All Implemented Interfaces:
public final class BetaResponseCodeInterpreterCallCodeDeltaEventEmitted when a partial code snippet is streamed by the code interpreter.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseCodeInterpreterCallCodeDeltaEvent.BuilderA builder for BetaResponseCodeInterpreterCallCodeDeltaEvent.
public final classBetaResponseCodeInterpreterCallCodeDeltaEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final Stringdelta()The partial code snippet being streamed by the code interpreter. final StringitemId()The unique identifier of the code interpreter tool call item. final LongoutputIndex()The index of the output item in the response for which the code is being streamed. final LongsequenceNumber()The sequence number of this event, used to order streaming events. final JsonValue_type()The type of the event. final Optional<BetaResponseCodeInterpreterCallCodeDeltaEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<String>_delta()Returns the raw JSON value of delta. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseCodeInterpreterCallCodeDeltaEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseCodeInterpreterCallCodeDeltaEvent.BuildertoBuilder()final BetaResponseCodeInterpreterCallCodeDeltaEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseCodeInterpreterCallCodeDeltaEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseCodeInterpreterCallCodeDeltaEvent. -
-
Method Detail
-
outputIndex
final Long outputIndex()
The index of the output item in the response for which the code is being streamed.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event, used to order streaming events.
-
_type
final JsonValue _type()
The type of the event. Always
response.code_interpreter_call_code.delta.Expected to always return the following:
JsonValue.from("response.code_interpreter_call_code.delta")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseCodeInterpreterCallCodeDeltaEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_delta
final JsonField<String> _delta()
Returns the raw JSON value of delta.
Unlike delta, this method doesn't throw if the JSON field has an unexpected type.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseCodeInterpreterCallCodeDeltaEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseCodeInterpreterCallCodeDeltaEvent.Builder toBuilder()
-
validate
final BetaResponseCodeInterpreterCallCodeDeltaEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseCodeInterpreterCallCodeDeltaEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseCodeInterpreterCallCodeDeltaEvent.
The following fields are required:
.delta() .itemId() .outputIndex() .sequenceNumber()
-
-
-
-