Class BetaResponseFunctionShellCallOutputContent.Builder
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellCallOutputContent.BuilderA builder for BetaResponseFunctionShellCallOutputContent.
-
-
Method Summary
-
-
Method Detail
-
outcome
final BetaResponseFunctionShellCallOutputContent.Builder outcome(BetaResponseFunctionShellCallOutputContent.Outcome outcome)
The exit or timeout outcome associated with this shell call.
-
outcome
final BetaResponseFunctionShellCallOutputContent.Builder outcome(JsonField<BetaResponseFunctionShellCallOutputContent.Outcome> outcome)
Sets Builder.outcome to an arbitrary JSON value.
You should usually call Builder.outcome with a well-typed Outcome value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outcome
final BetaResponseFunctionShellCallOutputContent.Builder outcome(BetaResponseFunctionShellCallOutputContent.Outcome.Exit exit)
Alias for calling outcome with
Outcome.ofExit(exit).
-
outcomeTimeout
final BetaResponseFunctionShellCallOutputContent.Builder outcomeTimeout()
Alias for calling outcome with
Outcome.ofTimeout().
-
exitOutcome
final BetaResponseFunctionShellCallOutputContent.Builder exitOutcome(Long exitCode)
Alias for calling outcome with the following:
Outcome.Exit.builder() .exitCode(exitCode) .build()
-
stderr
final BetaResponseFunctionShellCallOutputContent.Builder stderr(String stderr)
Captured stderr output for the shell call.
-
stderr
final BetaResponseFunctionShellCallOutputContent.Builder stderr(JsonField<String> stderr)
Sets Builder.stderr to an arbitrary JSON value.
You should usually call Builder.stderr with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stdout
final BetaResponseFunctionShellCallOutputContent.Builder stdout(String stdout)
Captured stdout output for the shell call.
-
stdout
final BetaResponseFunctionShellCallOutputContent.Builder stdout(JsonField<String> stdout)
Sets Builder.stdout to an arbitrary JSON value.
You should usually call Builder.stdout with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseFunctionShellCallOutputContent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseFunctionShellCallOutputContent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseFunctionShellCallOutputContent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseFunctionShellCallOutputContent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseFunctionShellCallOutputContent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseFunctionShellCallOutputContent build()
Returns an immutable instance of BetaResponseFunctionShellCallOutputContent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.outcome() .stderr() .stdout()
-
-
-
-