Class BetaResponseFunctionShellToolCall.Builder
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellToolCall.BuilderA builder for BetaResponseFunctionShellToolCall.
-
-
Method Summary
-
-
Method Detail
-
id
final BetaResponseFunctionShellToolCall.Builder id(String id)
The unique ID of the shell tool call. Populated when this item is returned via API.
-
id
final BetaResponseFunctionShellToolCall.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
action
final BetaResponseFunctionShellToolCall.Builder action(BetaResponseFunctionShellToolCall.Action action)
The shell commands and limits that describe how to run the tool call.
-
action
final BetaResponseFunctionShellToolCall.Builder action(JsonField<BetaResponseFunctionShellToolCall.Action> action)
Sets Builder.action to an arbitrary JSON value.
You should usually call Builder.action with a well-typed Action value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
callId
final BetaResponseFunctionShellToolCall.Builder callId(String callId)
The unique ID of the shell tool call generated by the model.
-
callId
final BetaResponseFunctionShellToolCall.Builder callId(JsonField<String> callId)
Sets Builder.callId to an arbitrary JSON value.
You should usually call Builder.callId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environment
final BetaResponseFunctionShellToolCall.Builder environment(BetaResponseFunctionShellToolCall.Environment environment)
Represents the use of a local environment to perform shell actions.
-
environment
final BetaResponseFunctionShellToolCall.Builder environment(Optional<BetaResponseFunctionShellToolCall.Environment> environment)
Alias for calling Builder.environment with
environment.orElse(null).
-
environment
final BetaResponseFunctionShellToolCall.Builder environment(JsonField<BetaResponseFunctionShellToolCall.Environment> environment)
Sets Builder.environment to an arbitrary JSON value.
You should usually call Builder.environment with a well-typed Environment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environment
final BetaResponseFunctionShellToolCall.Builder environment(BetaResponseLocalEnvironment local)
Alias for calling environment with
Environment.ofLocal(local).
-
environment
final BetaResponseFunctionShellToolCall.Builder environment(BetaResponseContainerReference containerReference)
Alias for calling environment with
Environment.ofContainerReference(containerReference).
-
containerReferenceEnvironment
final BetaResponseFunctionShellToolCall.Builder containerReferenceEnvironment(String containerId)
Alias for calling environment with the following:
BetaResponseContainerReference.builder() .containerId(containerId) .build()
-
status
final BetaResponseFunctionShellToolCall.Builder status(BetaResponseFunctionShellToolCall.Status status)
The status of the shell call. One of
in_progress,completed, orincomplete.
-
status
final BetaResponseFunctionShellToolCall.Builder status(JsonField<BetaResponseFunctionShellToolCall.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BetaResponseFunctionShellToolCall.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("shell_call")This method is primarily for setting the field to an undocumented or not yet supported value.
-
agent
final BetaResponseFunctionShellToolCall.Builder agent(BetaResponseFunctionShellToolCall.Agent agent)
The agent that produced this item.
-
agent
final BetaResponseFunctionShellToolCall.Builder agent(JsonField<BetaResponseFunctionShellToolCall.Agent> agent)
Sets Builder.agent to an arbitrary JSON value.
You should usually call Builder.agent with a well-typed Agent value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caller
final BetaResponseFunctionShellToolCall.Builder caller(BetaResponseFunctionShellToolCall.Caller caller)
The execution context that produced this tool call.
-
caller
final BetaResponseFunctionShellToolCall.Builder caller(Optional<BetaResponseFunctionShellToolCall.Caller> caller)
Alias for calling Builder.caller with
caller.orElse(null).
-
caller
final BetaResponseFunctionShellToolCall.Builder caller(JsonField<BetaResponseFunctionShellToolCall.Caller> caller)
Sets Builder.caller to an arbitrary JSON value.
You should usually call Builder.caller with a well-typed Caller value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caller
final BetaResponseFunctionShellToolCall.Builder caller(BetaResponseFunctionShellToolCall.Caller.Program program)
Alias for calling caller with
Caller.ofProgram(program).
-
callerDirect
final BetaResponseFunctionShellToolCall.Builder callerDirect()
Alias for calling caller with
Caller.ofDirect().
-
programCaller
final BetaResponseFunctionShellToolCall.Builder programCaller(String callerId)
Alias for calling caller with the following:
Caller.Program.builder() .callerId(callerId) .build()
-
createdBy
final BetaResponseFunctionShellToolCall.Builder createdBy(String createdBy)
The ID of the entity that created this tool call.
-
createdBy
final BetaResponseFunctionShellToolCall.Builder createdBy(JsonField<String> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseFunctionShellToolCall.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseFunctionShellToolCall.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseFunctionShellToolCall.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseFunctionShellToolCall.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseFunctionShellToolCall.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseFunctionShellToolCall build()
Returns an immutable instance of BetaResponseFunctionShellToolCall.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .action() .callId() .environment() .status()
-
-
-
-