Class BetaResponseFunctionShellToolCallOutput.Builder
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellToolCallOutput.BuilderA builder for BetaResponseFunctionShellToolCallOutput.
-
-
Method Summary
-
-
Method Detail
-
id
final BetaResponseFunctionShellToolCallOutput.Builder id(String id)
The unique ID of the shell call output. Populated when this item is returned via API.
-
id
final BetaResponseFunctionShellToolCallOutput.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
callId
final BetaResponseFunctionShellToolCallOutput.Builder callId(String callId)
The unique ID of the shell tool call generated by the model.
-
callId
final BetaResponseFunctionShellToolCallOutput.Builder callId(JsonField<String> callId)
Sets Builder.callId to an arbitrary JSON value.
You should usually call Builder.callId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxOutputLength
final BetaResponseFunctionShellToolCallOutput.Builder maxOutputLength(Long maxOutputLength)
The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.
-
maxOutputLength
final BetaResponseFunctionShellToolCallOutput.Builder maxOutputLength(Long maxOutputLength)
Alias for Builder.maxOutputLength.
This unboxed primitive overload exists for backwards compatibility.
-
maxOutputLength
final BetaResponseFunctionShellToolCallOutput.Builder maxOutputLength(Optional<Long> maxOutputLength)
Alias for calling Builder.maxOutputLength with
maxOutputLength.orElse(null).
-
maxOutputLength
final BetaResponseFunctionShellToolCallOutput.Builder maxOutputLength(JsonField<Long> maxOutputLength)
Sets Builder.maxOutputLength to an arbitrary JSON value.
You should usually call Builder.maxOutputLength with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
output
final BetaResponseFunctionShellToolCallOutput.Builder output(List<BetaResponseFunctionShellToolCallOutput.Output> output)
An array of shell call output contents
-
output
final BetaResponseFunctionShellToolCallOutput.Builder output(JsonField<List<BetaResponseFunctionShellToolCallOutput.Output>> output)
Sets Builder.output to an arbitrary JSON value.
You should usually call Builder.output with a well-typed
List<Output>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addOutput
final BetaResponseFunctionShellToolCallOutput.Builder addOutput(BetaResponseFunctionShellToolCallOutput.Output output)
Adds a single Output to Builder.output.
-
status
final BetaResponseFunctionShellToolCallOutput.Builder status(BetaResponseFunctionShellToolCallOutput.Status status)
The status of the shell call output. One of
in_progress,completed, orincomplete.
-
status
final BetaResponseFunctionShellToolCallOutput.Builder status(JsonField<BetaResponseFunctionShellToolCallOutput.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BetaResponseFunctionShellToolCallOutput.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("shell_call_output")This method is primarily for setting the field to an undocumented or not yet supported value.
-
agent
final BetaResponseFunctionShellToolCallOutput.Builder agent(BetaResponseFunctionShellToolCallOutput.Agent agent)
The agent that produced this item.
-
agent
final BetaResponseFunctionShellToolCallOutput.Builder agent(JsonField<BetaResponseFunctionShellToolCallOutput.Agent> agent)
Sets Builder.agent to an arbitrary JSON value.
You should usually call Builder.agent with a well-typed Agent value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caller
final BetaResponseFunctionShellToolCallOutput.Builder caller(BetaResponseFunctionShellToolCallOutput.Caller caller)
The execution context that produced this tool call.
-
caller
final BetaResponseFunctionShellToolCallOutput.Builder caller(Optional<BetaResponseFunctionShellToolCallOutput.Caller> caller)
Alias for calling Builder.caller with
caller.orElse(null).
-
caller
final BetaResponseFunctionShellToolCallOutput.Builder caller(JsonField<BetaResponseFunctionShellToolCallOutput.Caller> caller)
Sets Builder.caller to an arbitrary JSON value.
You should usually call Builder.caller with a well-typed Caller value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caller
final BetaResponseFunctionShellToolCallOutput.Builder caller(BetaResponseFunctionShellToolCallOutput.Caller.Program program)
Alias for calling caller with
Caller.ofProgram(program).
-
callerDirect
final BetaResponseFunctionShellToolCallOutput.Builder callerDirect()
Alias for calling caller with
Caller.ofDirect().
-
programCaller
final BetaResponseFunctionShellToolCallOutput.Builder programCaller(String callerId)
Alias for calling caller with the following:
Caller.Program.builder() .callerId(callerId) .build()
-
createdBy
final BetaResponseFunctionShellToolCallOutput.Builder createdBy(String createdBy)
The identifier of the actor that created the item.
-
createdBy
final BetaResponseFunctionShellToolCallOutput.Builder createdBy(JsonField<String> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseFunctionShellToolCallOutput.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseFunctionShellToolCallOutput.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseFunctionShellToolCallOutput.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseFunctionShellToolCallOutput.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseFunctionShellToolCallOutput.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseFunctionShellToolCallOutput build()
Returns an immutable instance of BetaResponseFunctionShellToolCallOutput.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .callId() .maxOutputLength() .output() .status()
-
-
-
-