Package com.openai.models.beta.threads
Class ThreadCreateAndRunParams.ToolResources.FileSearch
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.ToolResources.FileSearch
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.ToolResources.FileSearch.BuilderA builder for FileSearch.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>vectorStoreIds()The ID of the vector store attached to this assistant. final JsonField<List<String>>_vectorStoreIds()Returns the raw JSON value of vectorStoreIds. final Map<String, JsonValue>_additionalProperties()final ThreadCreateAndRunParams.ToolResources.FileSearch.BuildertoBuilder()final ThreadCreateAndRunParams.ToolResources.FileSearchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadCreateAndRunParams.ToolResources.FileSearch.Builderbuilder()Returns a mutable builder for constructing an instance of FileSearch. -
-
Method Detail
-
vectorStoreIds
final Optional<List<String>> vectorStoreIds()
The ID of the vector store attached to this assistant. There can be a maximum of 1 vector store attached to the assistant.
-
_vectorStoreIds
final JsonField<List<String>> _vectorStoreIds()
Returns the raw JSON value of vectorStoreIds.
Unlike vectorStoreIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.ToolResources.FileSearch.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.ToolResources.FileSearch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.ToolResources.FileSearch.Builder builder()
Returns a mutable builder for constructing an instance of FileSearch.
-
-
-
-