Package com.openai.models.evals
Class EvalCreateResponse.DataSourceConfig.Logs.Schema
-
- All Implemented Interfaces:
public final class EvalCreateResponse.DataSourceConfig.Logs.SchemaThe json schema for the run data source items. Learn how to build JSON schemas here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEvalCreateResponse.DataSourceConfig.Logs.Schema.BuilderA builder for Schema.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final EvalCreateResponse.DataSourceConfig.Logs.Schema.BuildertoBuilder()final EvalCreateResponse.DataSourceConfig.Logs.Schemavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EvalCreateResponse.DataSourceConfig.Logs.Schema.Builderbuilder()Returns a mutable builder for constructing an instance of Schema. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EvalCreateResponse.DataSourceConfig.Logs.Schema.Builder toBuilder()
-
validate
final EvalCreateResponse.DataSourceConfig.Logs.Schema validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EvalCreateResponse.DataSourceConfig.Logs.Schema.Builder builder()
Returns a mutable builder for constructing an instance of Schema.
-
-
-
-