Package com.openai.models.realtime
Class RealtimeResponseCreateAudioOutput
-
- All Implemented Interfaces:
public final class RealtimeResponseCreateAudioOutputConfiguration for audio input and output.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealtimeResponseCreateAudioOutput.BuilderA builder for RealtimeResponseCreateAudioOutput.
public final classRealtimeResponseCreateAudioOutput.Output
-
Method Summary
Modifier and Type Method Description final Optional<RealtimeResponseCreateAudioOutput.Output>output()final JsonField<RealtimeResponseCreateAudioOutput.Output>_output()Returns the raw JSON value of output. final Map<String, JsonValue>_additionalProperties()final RealtimeResponseCreateAudioOutput.BuildertoBuilder()final RealtimeResponseCreateAudioOutputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealtimeResponseCreateAudioOutput.Builderbuilder()Returns a mutable builder for constructing an instance of RealtimeResponseCreateAudioOutput. -
-
Method Detail
-
output
final Optional<RealtimeResponseCreateAudioOutput.Output> output()
-
_output
final JsonField<RealtimeResponseCreateAudioOutput.Output> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealtimeResponseCreateAudioOutput.Builder toBuilder()
-
validate
final RealtimeResponseCreateAudioOutput validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealtimeResponseCreateAudioOutput.Builder builder()
Returns a mutable builder for constructing an instance of RealtimeResponseCreateAudioOutput.
-
-
-
-