Package com.openai.models.responses
Class ResponseFunctionShellToolCall.Caller.Program.Builder
-
- All Implemented Interfaces:
public final class ResponseFunctionShellToolCall.Caller.Program.BuilderA builder for Program.
-
-
Method Summary
-
-
Method Detail
-
callerId
final ResponseFunctionShellToolCall.Caller.Program.Builder callerId(String callerId)
The call ID of the program item that produced this tool call.
-
callerId
final ResponseFunctionShellToolCall.Caller.Program.Builder callerId(JsonField<String> callerId)
Sets Builder.callerId to an arbitrary JSON value.
You should usually call Builder.callerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ResponseFunctionShellToolCall.Caller.Program.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("program")This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ResponseFunctionShellToolCall.Caller.Program.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ResponseFunctionShellToolCall.Caller.Program.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ResponseFunctionShellToolCall.Caller.Program.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ResponseFunctionShellToolCall.Caller.Program.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ResponseFunctionShellToolCall.Caller.Program.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ResponseFunctionShellToolCall.Caller.Program build()
Returns an immutable instance of Program.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.callerId()
-
-
-
-