Package com.openai.models.responses
Interface ResponseFunctionShellToolCall.Caller.Visitor
-
- All Implemented Interfaces:
public interface ResponseFunctionShellToolCall.Caller.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitDirect(JsonValue direct)abstract TvisitProgram(ResponseFunctionShellToolCall.Caller.Program program)Tunknown(JsonValue json)Maps an unknown variant of Caller to a value of type T. -
-
Method Detail
-
visitDirect
abstract T visitDirect(JsonValue direct)
-
visitProgram
abstract T visitProgram(ResponseFunctionShellToolCall.Caller.Program program)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Caller to a value of type T.
An instance of Caller can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-