Package com.openai.services.async
Interface AdminServiceAsync
-
- All Implemented Interfaces:
public interface AdminServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAdminServiceAsync.WithRawResponseA view of AdminServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AdminServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AdminServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract OrganizationServiceAsyncorganization()-
-
Method Detail
-
withRawResponse
abstract AdminServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AdminServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
organization
abstract OrganizationServiceAsync organization()
-
-
-
-