Class OrganizationServiceImpl
-
- All Implemented Interfaces:
-
com.openai.services.blocking.admin.OrganizationService
public final class OrganizationServiceImpl implements OrganizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOrganizationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OrganizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OrganizationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AuditLogServiceauditLogs()List user actions and configuration changes within this organization. AdminApiKeyServiceadminApiKeys()UsageServiceusage()InviteServiceinvites()UserServiceusers()GroupServicegroups()RoleServiceroles()DataRetentionServicedataRetention()SpendAlertServicespendAlerts()CertificateServicecertificates()ProjectServiceprojects()-
-
Method Detail
-
withRawResponse
OrganizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OrganizationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
auditLogs
AuditLogService auditLogs()
List user actions and configuration changes within this organization.
-
adminApiKeys
AdminApiKeyService adminApiKeys()
-
usage
UsageService usage()
-
invites
InviteService invites()
-
users
UserService users()
-
groups
GroupService groups()
-
roles
RoleService roles()
-
dataRetention
DataRetentionService dataRetention()
-
spendAlerts
SpendAlertService spendAlerts()
-
certificates
CertificateService certificates()
-
projects
ProjectService projects()
-
-
-
-